import 'package:flutter/material.dart';

class PhoenixButton extends StatelessWidget {
  const PhoenixButton({
    Key? key,
    required this.content,
    this.buttonMaterialStateProperty,
    this.buttonColor,
    this.buttonElevation,
    this.disableButtonColor,
    this.onPressed,
    this.radius,
    this.margin,
    this.padding,
    this.height,
    this.width,
    this.borderSide,
    this.textColor,
  }) : super(key: key);

  final Widget content;
  final MaterialStateProperty<Color>? buttonMaterialStateProperty;
  final Color? buttonColor;
  final Color? textColor;
  final Color? disableButtonColor;
  final double? buttonElevation;
  final double? radius;
  final EdgeInsets? margin;
  final EdgeInsets? padding;
  final double? height;
  final double? width;
  final VoidCallback? onPressed;
  final BorderSide? borderSide;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: margin ?? EdgeInsets.zero,
      child: ElevatedButton(
        style: (() {
          if (buttonMaterialStateProperty == null) {
            return ElevatedButton.styleFrom(
              primary: buttonColor,
              onPrimary: textColor,
              elevation: buttonElevation ?? 0.0,
              onSurface: disableButtonColor,
              shape: RoundedRectangleBorder(
                side: (() {
                  if (borderSide != null) {
                    return borderSide!;
                  } else {
                    return BorderSide.none;
                  }
                })(),
                borderRadius: BorderRadius.all(
                  Radius.circular(radius ?? 0.0),
                ),
              ),
            );
          } else {
            return ButtonStyle(
              elevation: MaterialStateProperty.all(0.0),
              shape: MaterialStateProperty.all(
                RoundedRectangleBorder(
                  side: borderSide ?? BorderSide.none,
                  borderRadius: BorderRadius.all(
                    Radius.circular(radius ?? 0.0),
                  ),
                ),
              ),
              backgroundColor: buttonMaterialStateProperty,
            );
          }
        })(),
        onPressed: onPressed,
        child: Wrap(
          children: [
            Container(
              height: height,
              width: (() {
                if (width == 0) {
                  return null;
                } else if (width == null) {
                  return double.infinity;
                } else {
                  return width;
                }
              })(),
              padding: padding,
              child: Center(
                child: content,
              ),
            ),
          ],
        ),
      ),
    );
  }
}
