import 'package:flutter/material.dart';

class PhoenixListview extends StatelessWidget {
  const PhoenixListview({
    Key? key,
    required this.title,
    required this.contents,
    this.seperatorSpace,
    this.seperatorColor,
    this.outlineBoxContentsColor,
    this.boxContentsColor,
    this.callback,
    this.action,
    this.radiusContentsBox,
  }) : super(key: key);

  final Widget title;
  final Radius? radiusContentsBox;
  final Color? seperatorColor;
  final List<Widget> contents;
  final double? seperatorSpace;
  final Color? outlineBoxContentsColor;
  final Color? boxContentsColor;
  final Function(int index)? callback;
  final Widget? action;

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Padding(
          padding: const EdgeInsets.only(
            left: 16,
            right: 16,
            top: 16,
          ),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              title,
              if (action != null) ...{action!}
            ],
          ),
        ),
        ListView.separated(
          shrinkWrap: true,
          physics: const NeverScrollableScrollPhysics(),
          padding: const EdgeInsets.symmetric(
            horizontal: 16,
            vertical: 8,
          ),
          itemCount: contents.length,
          separatorBuilder: (context, index) {
            return Row(
              children: [
                Container(
                  color: outlineBoxContentsColor ?? Colors.grey,
                  width: 1,
                  height: 1,
                ),
                Container(
                  color: boxContentsColor?? Colors.white,
                  height: 1,
                  width: seperatorSpace?? 16,
                ),
                Expanded(
                  child: Container(
                    color: seperatorColor ?? Colors.grey,
                    height: 1,
                  ),
                ),
              ],
            );
          },
          itemBuilder: (BuildContext context, int index) {
            return Material(
              color: Colors.white,
              child: InkWell(
                onTap: () {
                  if (callback != null) {
                    callback!(index);
                  }
                },
                child: Container(
                  decoration: BoxDecoration(
                    color: outlineBoxContentsColor ?? const Color(0xffEAEAEA),
                    borderRadius: contents.length > 1
                        ? index == 0
                            ? BorderRadius.only(
                                topRight: radiusContentsBox ??
                                    const Radius.circular(4),
                                topLeft: radiusContentsBox ??
                                    const Radius.circular(4),
                              )
                            : index == contents.length - 1
                                ? BorderRadius.only(
                                    bottomRight: radiusContentsBox ??
                                        const Radius.circular(4),
                                    bottomLeft: radiusContentsBox ??
                                        const Radius.circular(4),
                                  )
                                : null
                        : BorderRadius.all(
                            radiusContentsBox ?? const Radius.circular(4),
                          ),
                  ),
                  child: Container(
                    margin: contents.length > 1
                        ? index == 0
                            ? const EdgeInsetsDirectional.only(
                                start: 1,
                                end: 1,
                                top: 1,
                              )
                            : index == contents.length - 1
                                ? const EdgeInsetsDirectional.only(
                                    start: 1,
                                    end: 1,
                                    bottom: 1,
                                  )
                                : const EdgeInsetsDirectional.only(
                                    start: 1,
                                    end: 1,
                                  )
                        : const EdgeInsetsDirectional.all(1),
                    decoration: BoxDecoration(
                      color: boxContentsColor ?? Colors.white,
                      borderRadius: contents.length > 1
                          ? index == 0
                              ? BorderRadius.only(
                                  topLeft: radiusContentsBox ??
                                      const Radius.circular(4),
                                  topRight: radiusContentsBox ??
                                      const Radius.circular(4),
                                )
                              : index == contents.length - 1
                                  ? BorderRadius.only(
                                      bottomLeft: radiusContentsBox ??
                                          const Radius.circular(4),
                                      bottomRight: radiusContentsBox ??
                                          const Radius.circular(4),
                                    )
                                  : null
                          : const BorderRadius.all(Radius.circular(4)),
                    ),
                    padding: const EdgeInsets.symmetric(
                      horizontal: 16,
                      vertical: 12,
                    ),
                    child: contents[index],
                  ),
                ),
              ),
            );
          },
        ),
      ],
    );
  }
}
