import 'dart:async';

import 'package:flutter/material.dart';

class PhoenixSearchbar extends StatefulWidget {
  const PhoenixSearchbar({
    Key? key,
    this.hintText = "",
    this.fillColor = const Color(0xFFF9F9F9),
    this.borderColor = const Color(0xFFF9F9F9),
    this.enabled = true,
    this.isFocus = true,
    this.radius = 0,
    this.spaceBetween,
    this.actionWidget,
    this.searchIcon,
    this.textEditingController,
    this.hintTextStyle,
    this.padding,
    this.onWidgetTap,
    this.onChanged,
  }) : super(key: key);

  final String hintText;
  final Color fillColor;
  final Color borderColor;
  final bool enabled;
  final bool isFocus;
  final double radius;
  final double? spaceBetween;
  final Widget? actionWidget;
  final Widget? searchIcon;
  final TextEditingController? textEditingController;
  final TextStyle? hintTextStyle;
  final EdgeInsets? padding;
  final VoidCallback? onWidgetTap;
  final Function(String)? onChanged;

  @override
  State<PhoenixSearchbar> createState() => _PhoenixSearchbarState();
}

class _PhoenixSearchbarState extends State<PhoenixSearchbar> {
  final _debouncer = Debouncer();
  final _fnSearch = FocusNode();

  @override
  void initState() {
    super.initState();
    if (widget.isFocus) {
      _fnSearch.requestFocus();
    }
  }

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: !widget.enabled ? widget.onWidgetTap : null,
      child: Padding(
        padding: widget.padding ?? EdgeInsets.zero,
        child: Row(
          children: [
            Expanded(
              child: SizedBox(
                height: 34,
                child: TextField(
                  onChanged: (value) async {
                    _debouncer.run(() {
                      widget.onChanged?.call(value);
                    });
                  },
                  controller:
                      widget.textEditingController ?? TextEditingController(),
                  focusNode: _fnSearch,
                  enabled: widget.enabled,
                  decoration: InputDecoration(
                    enabled: widget.enabled,
                    contentPadding: EdgeInsets.zero,
                    fillColor: widget.fillColor,
                    filled: true,
                    isDense: true,
                    hintText: widget.hintText,
                    hintStyle: widget.hintTextStyle ??
                        const TextStyle(
                          color: Color(0xff75767A),
                          fontSize: 14,
                        ),
                    prefixIcon: widget.searchIcon ??
                        const Icon(
                          Icons.search,
                          size: 24,
                          color: Color(0xff75767A),
                        ),
                    focusedBorder: OutlineInputBorder(
                      borderRadius:
                          BorderRadius.all(Radius.circular(widget.radius)),
                      borderSide:
                          BorderSide(width: 0, color: widget.borderColor),
                    ),
                    disabledBorder: OutlineInputBorder(
                      borderRadius:
                          BorderRadius.all(Radius.circular(widget.radius)),
                      borderSide:
                          BorderSide(width: 0, color: widget.borderColor),
                    ),
                    enabledBorder: OutlineInputBorder(
                      borderRadius:
                          BorderRadius.all(Radius.circular(widget.radius)),
                      borderSide:
                          BorderSide(width: 0, color: widget.borderColor),
                    ),
                    border: OutlineInputBorder(
                      borderRadius:
                          BorderRadius.all(Radius.circular(widget.radius)),
                      borderSide:
                          BorderSide(width: 0, color: widget.borderColor),
                    ),
                  ),
                ),
              ),
            ),
            if (widget.actionWidget != null) ...[
              SizedBox(width: widget.spaceBetween ?? 0),
              widget.actionWidget!,
            ]
          ],
        ),
      ),
    );
  }
}

/// Use debouncer to detect user not in typing
class Debouncer {
  Duration? duration;
  VoidCallback? action;
  Timer? _timer;

  Debouncer({this.duration});

  run(VoidCallback action) {
    if (_timer != null) {
      _timer!.cancel();
    }
    _timer = Timer(duration ?? const Duration(milliseconds: 300), action);
  }
}
